@@ -25,13 +25,13 @@ def get_file_url(file_path: str):
     return FILE_URL.format(file_path=file_path)
 
 
-def parse_response(resp: Response, method: type[TgMethod]):
+def parse_response(method: type[TgMethod], params: dict, resp: Response):
     result: dict = resp.json()
 
     if result[OK]:
         result = result[RESULT]
     else:
-        raise RequestError(result[ERROR_CODE], result[DESCRIPTION])
+        raise RequestError(result[ERROR_CODE], result[DESCRIPTION], params)
 
     return cast(result, method.__response_type__)
 
@@ -61,4 +61,4 @@ def request(method: type[TgMethod], params: dict, **alternatives) -> TgObject |
 
     params = clean_dict(params)
     resp = session.post(endpoint, json=params)
-    return parse_response(resp, method)
+    return parse_response(method, params, resp)
