@@ -6,7 +6,7 @@ from ..filters.base import Filter
 
 @dataclass
 class Handler:
-    func: typing.Callable[[], None]
+    func: typing.Callable[..., None]
     filters: list[Filter] = field(default_factory=list)
     exclusive: bool = True
     check_first: bool = False
